@@ -26,6 +26,7 @@ Rattail Commands
 """
 
 from __future__ import unicode_literals
+from __future__ import absolute_import
 
 import os
 import re
@@ -46,9 +47,14 @@ class AdminCommand(Subcommand):
     description = "Launch 'SMS Admin' utility"
 
     def run(self, args):
-        from edbob.wx import LaunchDialog
+        import wx
         from rattail_locsms.wx.Admin import AdminDialog
-        LaunchDialog(AdminDialog)
+
+        app = wx.PySimpleApp()
+        dlg = AdminDialog(None)
+        dlg.ShowModal()
+        dlg.Destroy()
+        app.MainLoop()
 
 
 class GenerateSampleCommand(Subcommand):
