@@ -86,7 +86,7 @@ class CopyTransfer(Action):
 
     def __call__(self, csv_path):
         info = parse_filename(csv_path)
-        target_dir = config.require(
+        target_dir = self.config.require(
             'rattail.sw.locsms', 'transfers.{0}'.format(info.receiving_store))
         locking_copy(csv_path, target_dir)
 
